==> haskell-say-0.1.0.1-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-1X7CckeR5zEDEFYb497fad
key:                  say-0.1.0.1-1X7CckeR5zEDEFYb497fad
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  bc12e0a00d6fa8aa5dca5fa5bdce6462
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-say
hs-libraries:         HSsay-0.1.0.1-1X7CckeR5zEDEFYb497fad
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-say-0.1.0.1-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-NnbXHBqFO4GKxYDnfWr4K
key:                  say-0.1.0.1-NnbXHBqFO4GKxYDnfWr4K
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  88314c9e6134a806cc1a3350f8789619
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-say
hs-libraries:         HSsay-0.1.0.1-NnbXHBqFO4GKxYDnfWr4K
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
